
*************
Python module
*************

Type conversion
---------------

.. autosummary::

    shelephant.convert.flatten
    shelephant.convert.squash
    shelephant.convert.get
    shelephant.convert.split_key

yaml handling
-------------

.. autosummary::

    shelephant.yaml.read
    shelephant.yaml.read_item
    shelephant.yaml.dump
    shelephant.yaml.view

File operations
---------------

.. autosummary::

    shelephant.path.check_allisfile
    shelephant.path.filter_deepest
    shelephant.path.dirnames
    shelephant.path.makedirs
    shelephant.path.overwrite

File-path operations
--------------------

.. autosummary::

    shelephant.relpath.add_prefix
    shelephant.relpath.chroot

Checksum
--------

.. autosummary::

    shelephant.checksum.sha256
    shelephant.checksum.get

ssh queries
-----------

.. autosummary::

    shelephant.ssh.file_exists

scp copy
--------

.. autosummary::

    shelephant.scp.from_remote
    shelephant.scp.to_remote

rsync copy and queries
----------------------

.. autosummary::

    shelephant.rsync.diff
    shelephant.rsync.from_remote
    shelephant.rsync.to_remote

Formatted print
---------------

.. autosummary::

    shelephant.rich.theme
    shelephant.rich.String


Details
-------

.. automodule:: shelephant
  :members:
